import asyncio

from blockapi.block_expression import PlayExpression, ControlBehavior, SetMouthLamp, ControlMouthLamp
from dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown, test_start_run_program
from test.test_connect import test_get_device_by_name


async def test_play_expression():
    block: PlayExpression = PlayExpression(express_name="dance_0002")
    response = await block.execute()
    print(f'test_play_expression: {response}')


async def test_control_behavior():
    block: ControlBehavior = ControlBehavior(name="dance_0002")
    response = await block.execute()
    print(f'test_control_behavior: {response}')


async def test_set_mouth_lamp():
    block: SetMouthLamp = SetMouthLamp(color=1, duration=5000)
    response = await block.execute()
    print(f'test_set_mouth_lamp: {response}')


async def test_switch_mouth_lamp():
    response = await ControlMouthLamp(is_open=True).execute()
    print(f'test_switch_mouth_lamp: {response}')


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_play_expression())
        asyncio.get_event_loop().run_until_complete(test_control_behavior())
        asyncio.get_event_loop().run_until_complete(test_set_mouth_lamp())
        asyncio.get_event_loop().run_until_complete(test_switch_mouth_lamp())
        asyncio.get_event_loop().run_until_complete(shutdown())



#!/usr/bin/env python3

from blockapi.base_api import BaseBlockApi, DEFAULT_TIMEOUT
from blockapi.cmdid import PCProgramCmdId
from pb2.codemao_faceanalyze_pb2 import FaceAnalyzeRequest, FaceAnalyzeResponse
from pb2.codemao_facedetect_pb2 import FaceDetectResponse
from pb2.codemao_facerecognise_pb2 import FaceRecogniseRequest, FaceRecogniseResponse
from pb2.codemao_getinfrareddistance_pb2 import GetInfraredDistanceRequest, GetInfraredDistanceResponse
from pb2.codemao_getregisterfaces_pb2 import GetRegisterFacesRequest, GetRegisterFacesResponse
from pb2.codemao_recogniseobject_pb2 import RecogniseObjectRequest, RecogniseObjectResponse
from pb2.codemao_takepicture_pb2 import TakePictureRequest, TakePictureResponse
from pb2.pccodemao_message_pb2 import Message


class FaceDetect(BaseBlockApi):
    """
    人脸检测（个数）
    """

    def __init__(self, is_serial: bool = True, timeout: int = 0):
        assert timeout > 0, 'FaceDetect timeout should be positive'
        self.__isSerial = is_serial
        self.__timeout = timeout

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = FaceDetect()
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.FACE_DETECT_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceDetectResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class FaceAnalysis(BaseBlockApi):
    """
    人脸分析（性别）
    """

    def __init__(self, is_serial: bool = True, timeout: int = 0):
        assert timeout > 0, 'FaceAnalysis timeout should be positive'
        self.__isSerial = is_serial
        self.__timeout = timeout

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = FaceAnalyzeRequest()
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.FACE_ANALYSIS_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceAnalyzeResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ObjectRecognise(BaseBlockApi):
    """
    物体识别
    1(水果)  2（手势） 3（花)
    """

    def __init__(self, is_serial: bool = True, object_type: int = None, timeout: int = 0):
        assert timeout > 0, 'ObjectRecognise timeout should be positive'
        assert object_type is not None and object_type > 0, 'objectType should not be None,and should be positive'
        self.__isSerial = is_serial
        self.__objectType = object_type
        self.__timeout = timeout

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = RecogniseObjectRequest()
        request.objectType = self.__objectType
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.RECOGNISE_OBJECT_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = RecogniseObjectResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class FaceRecognise(BaseBlockApi):
    """
    人脸识别
    """

    def __init__(self, is_serial: bool = True, timeout: int = 0):
        assert timeout > 0, 'ObjectRecognise timeout should be positive'
        self.__isSerial = is_serial
        self.__timeout = timeout

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = FaceRecogniseRequest()
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class TakePicture(BaseBlockApi):
    """
    拍照
    """

    def __init__(self, is_serial: bool = True, ptype: int = 0):
        assert ptype > 0, 'ObjectRecognise timeout should be positive'
        self.__isSerial = is_serial
        self.__type = ptype

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = TakePictureRequest()
        request.type = self.__type

        cmd_id = PCProgramCmdId.TAKE_PICTURE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = TakePictureResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class GetInfraredDistance(BaseBlockApi):
    """
    获取红外距离
    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = GetInfraredDistanceRequest()

        cmd_id = PCProgramCmdId.GET_INFRARED_DISTANCE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = GetInfraredDistanceResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class GetRegisterFaces(BaseBlockApi):
    """
    获取已注册的人脸列表
    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = GetRegisterFacesRequest()

        cmd_id = PCProgramCmdId.GET_REGISTER_FACES_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = GetRegisterFacesResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_stopspeechrecognise.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_stopspeechrecognise.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n!codemao_stopspeechrecognise.proto\"\x1c\n\x1aStopSpeechRecogniseRequest\"D\n\x1bStopSpeechRecogniseResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_STOPSPEECHRECOGNISEREQUEST = _descriptor.Descriptor(
    name='StopSpeechRecogniseRequest',
    full_name='StopSpeechRecogniseRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=65,
)

_STOPSPEECHRECOGNISERESPONSE = _descriptor.Descriptor(
    name='StopSpeechRecogniseResponse',
    full_name='StopSpeechRecogniseResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='StopSpeechRecogniseResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='StopSpeechRecogniseResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=67,
    serialized_end=135,
)

DESCRIPTOR.message_types_by_name['StopSpeechRecogniseRequest'] = _STOPSPEECHRECOGNISEREQUEST
DESCRIPTOR.message_types_by_name['StopSpeechRecogniseResponse'] = _STOPSPEECHRECOGNISERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StopSpeechRecogniseRequest = _reflection.GeneratedProtocolMessageType('StopSpeechRecogniseRequest', (_message.Message,),
                                                                      {
                                                                          'DESCRIPTOR': _STOPSPEECHRECOGNISEREQUEST,
                                                                          '__module__': 'codemao_stopspeechrecognise_pb2'
                                                                          # @@protoc_insertion_point(class_scope:StopSpeechRecogniseRequest)
                                                                      })
_sym_db.RegisterMessage(StopSpeechRecogniseRequest)

StopSpeechRecogniseResponse = _reflection.GeneratedProtocolMessageType('StopSpeechRecogniseResponse',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _STOPSPEECHRECOGNISERESPONSE,
                                                                           '__module__': 'codemao_stopspeechrecognise_pb2'
                                                                           # @@protoc_insertion_point(class_scope:StopSpeechRecogniseResponse)
                                                                       })
_sym_db.RegisterMessage(StopSpeechRecogniseResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

import os
import sys

BASE = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, BASE)

from blockapi.block_action import PlayAction, MoveRobot
from dns.dns_browser import WiFiDevice
from test.test_connect import test_get_device_by_name, test_start_run_program, test_stop_run_program
from test.test_connect import test_connect, shutdown


async def test_play_action():
    block: PlayAction = PlayAction(action_name='dance_0002')
    response = await block.execute()
    print(f'test_play_action: {response}')


async def test_move_robot():
    block: MoveRobot = MoveRobot(step=10, direction=1)
    response = await block.execute()
    print(f'test_move_robot: {response}')


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_play_action())
        asyncio.get_event_loop().run_until_complete(test_move_robot())
        asyncio.get_event_loop().run_until_complete(shutdown())



import asyncio

from mini.blockapi.block_observe import ObserveInfraredDistance
from mini.blockapi.block_sound import PlayTTS
from mini.dns.dns_browser import WiFiDevice

from test_connect import test_connect, shutdown
from test_connect import test_get_device_by_name, test_start_run_program


async def test_ObserveInfraredDistance():
    observer: ObserveInfraredDistance = ObserveInfraredDistance()

    def handler(msg):
        print("{0}".format(str(msg.distance)))
        if msg.distance < 500:
            asyncio.create_task(__tts())

    observer.set_handler(handler)
    observer.start()
    await asyncio.sleep(0)


async def __tts():
    await PlayTTS(text="是不是有人在啊， 你是谁啊").execute()


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_ObserveInfraredDistance())
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())



#!/usr/bin/env python3

from blockapi.base_api import BaseBlockApi, DEFAULT_TIMEOUT
from blockapi.cmdid import PCProgramCmdId
from pb2 import cloudstorageurls_pb2
from pb2.cloudtranslate_pb2 import Platform
from pb2.codemao_controltts_pb2 import ControlTTSRequest, ControlTTSResponse
from pb2.codemao_getaudiolist_pb2 import GetAudioListRequest, GetAudioListResponse
from pb2.codemao_playaudio_pb2 import PlayAudioRequest, PlayAudioResponse
from pb2.codemao_playonlinemusic_pb2 import MusicRequest, MusicResponse
from pb2.codemao_stopaudio_pb2 import StopAudioRequest, StopAudioResponse
from pb2.pccodemao_message_pb2 import Message


class PlayTTS(BaseBlockApi):
    """
    播放TTS
    type: 1 播放 0 停止播放
    """

    def __init__(self, is_serial: bool = True, text: str = None, _type: int = 1):
        assert text is not None, 'tts text could not be None'
        self.__isSerial = is_serial
        self.__text = text
        self.__type = _type

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = ControlTTSRequest()
        request.text = self.__text
        request.type = self.__type

        cmd_id = PCProgramCmdId.PLAY_TTS_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlTTSResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class PlayAudio(BaseBlockApi):
    """
    播放音效
    默认音效存储类型为阿里私有云
    """

    def __init__(self, is_serial: bool = True, url: str = None, volume: float = 0):
        assert url is not None, 'str could not be None'
        self.__isSerial = is_serial
        self.__url = url
        self.__volume = volume
        self.__cloudStorageType = cloudstorageurls_pb2.ALIYUN_PRIVATE

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        cloud = cloudstorageurls_pb2.CloudStorage()
        cloud.type = self.__cloudStorageType
        cloud.url.extend(list(self.__url))

        request = PlayAudioRequest()

        request.cloud.CopyFrom(cloud)
        request.volume = self.__volume

        cmd_id = PCProgramCmdId.PLAY_AUDIO_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayAudioResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopAllAudio(BaseBlockApi):
    """
    停止所有音效
    """

    def __init__(self, is_serial: bool = True, ):
        self.__isSerial = is_serial

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = StopAudioRequest()

        cmd_id = PCProgramCmdId.STOP_AUDIO_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = StopAudioResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class FetchAudioList(BaseBlockApi):
    """
    获取机器人的音效列表
    """

    def __init__(self, is_serial: bool = True, search_type: int = 0):
        self.__isSerial = is_serial
        self.__searchType = search_type

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = GetAudioListRequest()

        request.searchType = self.__searchType

        cmd_id = PCProgramCmdId.GET_AUDIO_LIST_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = GetAudioListResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class PlayOnlineMusic(BaseBlockApi):
    """
    播放在线歌曲
    默认腾讯平台
    """

    def __init__(self, is_serial: bool = True, name: str = None):
        assert name is not None and len(name), 'PlayOnlineMusic name should be available'
        self.__isSerial = is_serial
        self.__name = name
        self.__platform = Platform.TENCENT

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = MusicRequest()

        request.platform = self.__platform
        request.name = self.__name

        cmd_id = PCProgramCmdId.PLAY_ONLINE_MUSIC_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = MusicResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



#!/usr/bin/env python3

from blockapi.base_api import BaseBlockApi, DEFAULT_TIMEOUT
from blockapi.cmdid import PCProgramCmdId
from pb2.codemao_controlbehavior_pb2 import ControlBehaviorRequest, ControlBehaviorResponse
from pb2.codemao_controlmouthlamp_pb2 import ControlMouthRequest, ControlMouthResponse
from pb2.codemao_playexpression_pb2 import PlayExpressionRequest, PlayExpressionResponse
from pb2.codemao_setmouthlamp_pb2 import SetMouthLampRequest, SetMouthLampResponse
from pb2.pccodemao_message_pb2 import Message


class PlayExpression(BaseBlockApi):
    """
    播放表情
    """

    def __init__(self, is_serial: bool = True, express_name: str = None, dir_type: int = 0):
        assert express_name is not None, 'PlayExpression expressName could not be None'
        self.__isSerial = is_serial
        self.__expressName = express_name
        self.__dirType = dir_type

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = PlayExpressionRequest()
        request.expressName = self.__expressName
        request.dirType = self.__dirType

        cmd_id: int = PCProgramCmdId.PLAY_EXPRESSION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayExpressionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ControlBehavior(BaseBlockApi):
    """
    控制表现力
    """

    # TODO 控制表现力接口， 如果event_type不传的话，实际调用到了停止表现力， event_type =0 是停止的意思
    def __init__(self, is_serial: bool = True, name: str = None, event_type: int = 1):
        assert name is not None, 'ControlBehavior name could not be None'
        self.__isSerial = is_serial
        self.__name = name
        self.__eventType = event_type

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = ControlBehaviorRequest()
        request.name = self.__name
        request.eventType = self.__eventType

        cmd_id = PCProgramCmdId.CONTROL_BEHAVIOR_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlBehaviorResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class SetMouthLamp(BaseBlockApi):
    """
    设置嘴巴灯
    """

    def __init__(self, is_serial: bool = True, model: int = 0, color: int = 0, duration: int = 0,
                 breath_duration: int = 0):

        self.__isSerial = is_serial
        self.__model = model
        self.__color = color
        self.__duration = duration
        self.__breathDuration = breath_duration

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = SetMouthLampRequest()
        request.model = self.__model
        request.color = self.__color
        request.duration = self.__duration
        request.breathDuration = self.__breathDuration

        cmd_id = PCProgramCmdId.SET_MOUTH_LAMP_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = SetMouthLampResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ControlMouthLamp(BaseBlockApi):
    """
    控制嘴巴灯开关
    """

    def __init__(self, is_serial: bool = True, is_open: bool = False):

        self.__isSerial = is_serial
        self.__isOpen = is_open

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = ControlMouthRequest()
        request.isOpen = self.__isOpen

        cmd_id = PCProgramCmdId.SWITCH_MOUTH_LAMP_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlMouthResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



import asyncio

import os
import sys

BASE = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, BASE)

from blockapi.block_sound import PlayTTS, PlayAudio, FetchAudioList, StopAllAudio
from dns.dns_browser import WiFiDevice
from test.test_connect import test_get_device_by_name, test_start_run_program
from test.test_connect import test_connect, shutdown


async def test_play_tts():
    block: PlayTTS = PlayTTS(text="你好， 我是悟空， 啦啦啦")
    response = await block.execute()
    print(f'tes_play_tts: {response}')


async def test_play_audio():
    block: PlayAudio = PlayAudio(
        url="http://yun.lnpan.com/music/download/ring/000/075/5653bae83917a892589b372782175dd8.amr")
    response = await block.execute()
    print(f'test_play_audio: {response}')


async def test_get_audio_list():
    block: FetchAudioList = FetchAudioList()
    response = await block.execute()
    print(f'test_get_audio_list: {response}')


async def test_stop_audio():
    block: PlayTTS = PlayTTS(is_serial=False, text="你让我说，让我说，不要打断我，不要打断我，不要打断我")
    response = await block.execute()
    print(f'test_stop_audio.play_tts: {response}')
    await asyncio.sleep(2)
    block: StopAllAudio = StopAllAudio()
    response = await block.execute()
    print(f'test_stop_audio.stop_all_audio:{response}')


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_play_tts())
        asyncio.get_event_loop().run_until_complete(test_play_audio())
        asyncio.get_event_loop().run_until_complete(test_get_audio_list())
        asyncio.get_event_loop().run_until_complete(test_stop_audio())
        asyncio.get_event_loop().run_until_complete(shutdown())



import asyncio

from blockapi.block_expression import ControlBehavior
from blockapi.block_observe import ObserveHeadRacket
from dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


async def test_ObserveHeadRacket():
    observer: ObserveHeadRacket = ObserveHeadRacket()

    def handler(msg):
        print("{0}".format(str(msg.type)))
        asyncio.run(__dance())

    observer.set_handler(handler)
    observer.start()
    await asyncio.sleep(0)


async def __dance():
    await ControlBehavior(name="dance_0002").execute()


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_ObserveHeadRacket())
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())



import asyncio

from blockapi.block_content import QueryWiKi, StartTranslate
from dns.dns_browser import WiFiDevice
from pb2.cloudtranslate_pb2 import CN, EN
from test.test_connect import test_connect, shutdown, test_start_run_program
from test.test_connect import test_get_device_by_name


async def test_query_wiki():
    block: QueryWiKi = QueryWiKi(query='优必选')
    response = await block.execute()
    print(f'test_query_wiki: {response}')


async def test_start_translate():
    block: StartTranslate = StartTranslate(query="张学友", from_lan=CN, to_lan=EN)
    response = await block.execute()
    print(f'test_start_translate: {response}')


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_query_wiki())
        asyncio.get_event_loop().run_until_complete(test_start_translate())
        asyncio.get_event_loop().run_until_complete(shutdown())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_searchfaces.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_searchfaces.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x19\x63odemao_searchfaces.proto\"&\n\x12SearchFacesRequest\x12\x10\n\x08isSearch\x18\x01 \x01(\x08\"<\n\x13SearchFacesResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_SEARCHFACESREQUEST = _descriptor.Descriptor(
    name='SearchFacesRequest',
    full_name='SearchFacesRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSearch', full_name='SearchFacesRequest.isSearch', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=29,
    serialized_end=67,
)

_SEARCHFACESRESPONSE = _descriptor.Descriptor(
    name='SearchFacesResponse',
    full_name='SearchFacesResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='SearchFacesResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='SearchFacesResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=69,
    serialized_end=129,
)

DESCRIPTOR.message_types_by_name['SearchFacesRequest'] = _SEARCHFACESREQUEST
DESCRIPTOR.message_types_by_name['SearchFacesResponse'] = _SEARCHFACESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchFacesRequest = _reflection.GeneratedProtocolMessageType('SearchFacesRequest', (_message.Message,), {
    'DESCRIPTOR': _SEARCHFACESREQUEST,
    '__module__': 'codemao_searchfaces_pb2'
    # @@protoc_insertion_point(class_scope:SearchFacesRequest)
})
_sym_db.RegisterMessage(SearchFacesRequest)

SearchFacesResponse = _reflection.GeneratedProtocolMessageType('SearchFacesResponse', (_message.Message,), {
    'DESCRIPTOR': _SEARCHFACESRESPONSE,
    '__module__': 'codemao_searchfaces_pb2'
    # @@protoc_insertion_point(class_scope:SearchFacesResponse)
})
_sym_db.RegisterMessage(SearchFacesResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
